[hide private]
[frames] | no frames]

[ Module Hierarchy | Class Hierarchy ]

# Class Hierarchy

- exceptions.Exception: Common base class for all exceptions.
  - spoon.transports.TransportException
  - spoon.routing.meshrouter.RoutingProtocolError
    - spoon.routing.meshrouter.NodeUnreachable: Raised when trying to send to a node that is not currently reachable.
  - spoon.ber.BERException
- object: The most base type
  - spoon.messaging.Messaging: This is the main messaging class that implements the basic functionality for Spoon.
    - spoon.messaging.SingletonMessaging: For convinience this is a singleton version of the Messaging system.
  - spoon.ber.zencoder
  - spoon.ber.stream.CountingFile
  - spoon.routing.meshrouter.MeshRouter: This class handles LMTYPE_NETWORK messages and LMTYPE_NETWORK_PROTO messages.
  - spoon.transports.LinkMessage: Link message is the wrapper which will contain messages sent between two directly connected nodes.
  - spoon.ber.BERStream: FIXME docs
  - spoon.routing.meshrouter.NetMessage: NetMessage is the protocol unit for the networking component of spoon.
  - dict: dict() -> new empty dictionary.
    - spoon.spooncore.LazyDict
  - spoon.spooncore.Memoizer: Used as a substitute for the file object when serializing Serial objects, so reference cycles are caught and handled.
  - spoon.serialprop: When used like a property in a Serial class, it will act as a flag to the serializer that only properties that are of type `serialprop` or `lazyprop` are to be serialized.
  - spoon.ber.decoder
  - spoon.ber.encoder
  - threading._Verbose
    - threading.Thread
      - spoon.transports.spoontransport.SpoonTransportThread
  - spoon.Serial
    - spoon.transports.SpoonRPCHello: This object is sent as a very simple form of initial negotiation.
  - spoon.transports.TransportHub: Where all of your transports connect to form your glorious new node.
  - spoon.transports.SpoonTransport: The spoon transport base class.
  - spoon.spooncore.SpoonData
  - spoon.NullLogger: Dummy logging object.
  - spoon.messaging.receive: The receive decorator can be used to decorate functions and static methods (NOT methods of class instances) that should receive messages of a given type.
  - spoon.ber.Tag: Representation of the header of an ASN.1 object.
  - spoon.spoonstream.SocketFile: Simple wrapper around a socket like object that pretends to be a file.
  - spoon.SpoonStream: SpoonStream implements an object stream.
  - property: property(fget=None, fset=None, fdel=None, doc=None) -> property attribute fget is a function to be used for getting an attribute value, and likewise fset is a function for setting, and fdel a function for del'ing, an attribute.
    - spoon.lazyprop: When used like a property in a Serial class, it will act as a flag to the serializer that only properties that are of type `serialprop` or `lazyprop` are to be serialized.
  - spoon.spooncore.StringIOWrap: Stupid wrapper around StringIO because it isn't a new style class.
  - type: type(object) -> the object's type type(name, bases, dict) -> a new type
    - spoon.spooncore.SerialMeta